## R Version 3.4.2
## This script graphs estimated hereozygosity from the ipyrad "_stats.txt" files.

library("ggplot2")

# I read in the files with 74 in the name, because this is a subset of 74 samples. (37 from each species)
sored_74_stats <- read.table("./74_sored_stats.txt", header = TRUE, fill = TRUE)
shock_74_stats <- read.table("./74_shock_stats.txt", header = TRUE, fill = TRUE)

mean(sored_74_stats$hetero_est)
sd(sored_74_stats$hetero_est)
mean(shock_74_stats$hetero_est)
sd(shock_74_stats$hetero_est)

mean(sored_74_stats$reads_consens)
mean(shock_74_stats$reads_consens)

ggplot(data=shock_74_stats, aes(shock_74_stats$hetero_est)) + 
  geom_histogram(breaks=seq(0.004,0.028, by=0.001), 
                 col="black", 
                 fill="#458B74", 
                 alpha = 1) + 
  ggtitle("Estimated Heterozygosity in E. shockleyi") +
  theme(plot.title = element_text(hjust = 0.5)) +
  theme(plot.title = element_text(size=22)) +
  theme(text = element_text(size=18)) +
  labs(x="Estimated Heterozygosity", y="Frequency of Individuals") + 
  xlim(c(0.003,0.027)) + 
  ylim(c(0,17)) +
  geom_vline(xintercept = mean(shock_74_stats$hetero_est), col = "black", size = 1.7) 

ggplot(data=sored_74_stats, aes(sored_74_stats$hetero_est)) + 
  geom_histogram(breaks=seq(0.004,0.028, by=0.001), 
                 col="black", 
                 fill="#FF7F50", 
                 alpha = 1) + 
  ggtitle("Estimated Heterozygosity in E. soredium") +
  theme(plot.title = element_text(hjust = 0.5)) +
  theme(plot.title = element_text(size=22)) +
  theme(text = element_text(size=18)) +
  labs(x="Estimated Heterozygosity", y="Frequency of Individuals") + 
  xlim(c(0.003,0.027)) + 
  ylim(c(0,17)) +
  geom_vline(xintercept = mean(sored_74_stats$hetero_est), col = "black", size = 1.7) 

t.test(shock_74_stats$hetero_est, sored_74_stats$hetero_est)

"	
Welch Two Sample t-test

data:  sored_74_stats$hetero_est and shock_74_stats$hetero_est
t = -3.3296, df = 70.886, p-value = 0.001383
alternative hypothesis: true difference in means is not equal to 0
95 percent confidence interval:
-0.004085886 -0.001025087
sample estimates:
mean of x  mean of y 
0.01270478 0.01526027

"
